==> idwise_flutter_sdk-0.1.5.tar.gz: lib/idwise_flutter_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'idwise_flutter.dart';
import 'idwise_flutter_method_channel.dart';

abstract class IdwiseFlutterPlatform extends PlatformInterface {
  /// Constructs a IdwiseFlutterPlatform.
  IdwiseFlutterPlatform() : super(token: _token);

  static final Object _token = Object();

  static IdwiseFlutterPlatform _instance = MethodChannelIdwiseFlutter();

  /// The default instance of [IdwiseFlutterPlatform] to use.
  ///
  /// Defaults to [MethodChannelIdwiseFlutter].
  static IdwiseFlutterPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [IdwiseFlutterPlatform] when
  /// they register themselves.
  static set instance(IdwiseFlutterPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  void initialize(String clientKey, IDWiseSDKTheme theme,
      {required onError(String error)}) {
    throw UnimplementedError('initialize() has not been implemented.');
  }

  void startJourney(String journeyDefinitionId, String referenceNo,
      String locale, IDWiseSDKJourneyCallbacks journeyCallbacks) {
    throw UnimplementedError('startJourney() has not been implemented.');
  }

  void startDynamicJourney(
      String journeyDefinitionId,
      String referenceNo,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    throw UnimplementedError('startDynamicJourney() has not been implemented.');
  }

  void resumeDynamicJourney(
      String journeyDefinitionId,
      String journeyId,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    throw UnimplementedError(
        'resumeDynamicJourney() has not been implemented.');
  }

  void getJourneySummary(String journeyId, {required journeySummary}) {
    throw UnimplementedError('getJourneySummary() has not been implemented.');
  }

  void startStep(String stepId) {
    throw UnimplementedError('startStep() has not been implemented.');
  }

  void unloadSDK() {
    throw UnimplementedError('unloadSDK() has not been implemented.');
  }
}

==> idwise_flutter_sdk-1.0.1-rc.2.tar.gz: lib/idwise_flutter_platform_interface.dart <==
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'idwise_flutter.dart';
import 'idwise_flutter_method_channel.dart';

abstract class IdwiseFlutterPlatform extends PlatformInterface {
  /// Constructs a IdwiseFlutterPlatform.
  IdwiseFlutterPlatform() : super(token: _token);

  static final Object _token = Object();

  static IdwiseFlutterPlatform _instance = MethodChannelIdwiseFlutter();

  /// The default instance of [IdwiseFlutterPlatform] to use.
  ///
  /// Defaults to [MethodChannelIdwiseFlutter].
  static IdwiseFlutterPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [IdwiseFlutterPlatform] when
  /// they register themselves.
  static set instance(IdwiseFlutterPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  void initialize(String clientKey, IDWiseSDKTheme theme,
      {required onError(String error)}) {
    throw UnimplementedError('initialize() has not been implemented.');
  }

  void startJourney(String journeyDefinitionId, String referenceNo,
      String locale, IDWiseSDKJourneyCallbacks journeyCallbacks) {
    throw UnimplementedError('startJourney() has not been implemented.');
  }

  void startDynamicJourney(
      String journeyDefinitionId,
      String referenceNo,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    throw UnimplementedError('startDynamicJourney() has not been implemented.');
  }

  void resumeDynamicJourney(
      String journeyDefinitionId,
      String journeyId,
      String locale,
      IDWiseSDKJourneyCallbacks journeyCallbacks,
      IDWiseSDKStepCallbacks stepCallbacks) {
    throw UnimplementedError(
        'resumeDynamicJourney() has not been implemented.');
  }

  void getJourneySummary({required journeySummary}) {
    throw UnimplementedError('getJourneySummary() has not been implemented.');
  }

  void finishDynamicJourney() {
    throw UnimplementedError(
        'finishDynamicJourney() has not been implemented.');
  }

  void startStep(String stepId) {
    throw UnimplementedError('startStep() has not been implemented.');
  }

  void skipStep(String stepId) {
    throw UnimplementedError('skipStep() has not been implemented.');
  }

  void unloadSDK() {
    throw UnimplementedError('unloadSDK() has not been implemented.');
  }
}
